
https://github.com/entron/entity-embedding-rossmann

https://www.kaggle.com/aquatic/entity-embedding-neural-net/code

https://github.com/entron/entity-embedding-rossmann

https://github.com/entron/entity-embedding-rossmann/blob/master/train_test_model.py


https://github.com/nplay007/kaggle/blob/master/rossman/entity-embedding-rossmann/models.py

https://github.com/manuel-calzolari/keras-cat

https://github.com/timdavidlee/EmbeddingCatNet
